Struct
QmiMessagePbmGetCapabilitiesInput
since: 1.6
Description [src]
struct QmiMessagePbmGetCapabilitiesInput {
/* No available fields */
}
The QmiMessagePbmGetCapabilitiesInput structure contains private data and should only be accessed
using the provided API.
Available since: 1.6
Constructors
qmi_message_pbm_get_capabilities_input_new
Allocates a new QmiMessagePbmGetCapabilitiesInput.
since: 1.6
Instance methods
qmi_message_pbm_get_capabilities_input_get_phonebook_information
Get the ‘Phonebook Information’ field from self.
since: 1.6
qmi_message_pbm_get_capabilities_input_ref
Atomically increments the reference count of self by one.
since: 1.6
qmi_message_pbm_get_capabilities_input_set_phonebook_information
Set the ‘Phonebook Information’ field in the message.
since: 1.6
qmi_message_pbm_get_capabilities_input_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.6